===================================
Detailed User Interface Information
===================================

Sensitivity
-----------
The main module in `hasasia` is the Sensitivity module which contains all of the
needed methods for building a senstivity curve.

.. automodule:: hasasia.sensitivity
    :members:
    :inherited-members:

Skymap
------
The `hasasia.Skymap` module contains the methods necessary for making
sensitivity maps for pulsar timing array.

.. automodule:: hasasia.skymap
    :members:
    :inherited-members:

Utils
-----
.. automodule:: hasasia.utils
    :members:
    :inherited-members:

Simulations
-----------
.. automodule:: hasasia.sim
    :members:
    :inherited-members:
